# linkedin-matrix

[![pipeline status](https://gitlab.com/beeper/linkedin-matrix/badges/master/pipeline.svg)](https://gitlab.com/beeper/linkedin-matrix/-/commits/master) 
[![Matrix Chat](https://img.shields.io/matrix/linkedin-matrix:nevarro.space?server_fqdn=matrix.nevarro.space)](https://matrix.to/#/#linkedin-matrix:nevarro.space?via=nevarro.space&via=sumnerevans.com)
[![Apache 2.0](https://img.shields.io/github/license/sumnerevans/linkedin-matrix)](https://github.com/sumnerevans/linkedin-matrix/blob/master/LICENSE)

LinkedIn Messaging <-> Matrix bridge built using
[mautrix-python](https://github.com/tulir/mautrix-python) and
[linkedin-messaging-api](https://github.com/sumnerevans/linkedin-messaging-api).

## Documentation

Not any yet :)

### Features & Roadmap
[ROADMAP.md](https://github.com/sumnerevans/linkedin-matrix/blob/master/ROADMAP.md)
contains a general overview of what is supported by the bridge.

## Discussion

Matrix room:
[`#linkedin-matrix:nevarro.space`](https://matrix.to/#/#linkedin-matrix:nevarro.space?via=nevarro.space&via=sumnerevans.com)
